@@ -77,6 +77,12 @@ enum ast_cel_event_type {
 	AST_CEL_LOCAL_OPTIMIZE = 17,
 	/*! \brief A local channel optimization has begun */
 	AST_CEL_LOCAL_OPTIMIZE_BEGIN = 18,
+	/*! \brief A stream started */
+	AST_CEL_STREAM_BEGIN = 19,
+	/*! \brief A stream ended */
+	AST_CEL_STREAM_END = 20,
+	/*! \brief A DTMF digit was processed */
+	AST_CEL_DTMF = 21,
 };
 
 /*!
@@ -140,7 +146,7 @@ struct ast_cel_event_record {
 	 * \brief struct ABI version
 	 * \note This \b must be incremented when the struct changes.
 	 */
-	#define AST_CEL_EVENT_RECORD_VERSION 2
+	#define AST_CEL_EVENT_RECORD_VERSION 3
 	/*!
 	 * \brief struct ABI version
 	 * \note This \b must stay as the first member.
@@ -164,6 +170,7 @@ struct ast_cel_event_record {
 	const char *peer_account;
 	const char *unique_id;
 	const char *linked_id;
+	const char *tenant_id;
 	uint amaflag;
 	const char *user_field;
 	const char *peer;
@@ -195,6 +202,22 @@ void ast_cel_publish_event(struct ast_channel *chan,
 	enum ast_cel_event_type event_type,
 	struct ast_json *blob);
 
+/*!
+ * \brief Publish a CEL user event
+ * \since 18
+ *
+ * \note
+ * This serves as a wrapper function around ast_cel_publish_event() to help pack the
+ * extra details before publishing.
+ *
+ * \param chan This is the primary channel associated with this channel event.
+ * \param event This is the user event being reported.
+ * \param extra This contains any extra parameters that need to be conveyed for this event.
+ */
+void ast_cel_publish_user_event(struct ast_channel *chan,
+	const char *event,
+	const char *extra);
+
 /*!
  * \brief Get the CEL topic
  *
